# Greener Pytest Plugin 
Pytest plugin for [Greener](https://github.com/cephei8/greener).

## Contributing
See [CONTRIBUTING.md](https://github.com/cephei8/pytest-greener/blob/main/CONTRIBUTING.md).

## License
This project is licensed under the terms of the [Apache License 2.0](./LICENSE).
